# __init__.py
__version__ = "0.1"

from os import chdir, getcwd, getenv
from os.path import abspath, exists, expanduser
import platform
import macos
from shell import shell

def islinux():
    return platform.system()=="Linix"

def ismacos():
    return platform.system()=="Darwin"

def iswindows():
    return platform.system()=="Windows"

def name():
    """return "python setup.py --name" """
    setup=abspath(expanduser("setup.py"))
    if exists(setup):
        return shell("python setup.py --name").splitlines()[-1]

def version():
    """return "python setup.py --version" """
    setup=abspath(expanduser("setup.py"))
    if exists(setup):
        return shell("python setup.py --version").splitlines()[-1]


def check(bin="python",f="setup.py"):
    """return True if "python setup.py check" succesfull """
    f=abspath(expanduser(f))
    if exists(f):
        pwd = getcwd()
        # change current dir to testing relative paths
        chdir(getenv("HOME")) 
        try:
            command="%s %s check" % (bin,f)
            shell(command)
            chdir(pwd) # return current dir
        except Exception, e:
            chdir(pwd) # return current dir
            raise Exception(str(e))
    return True

def install(bin="python",f="setup.py"):
    """run "python setup.py install" """
    f=abspath(expanduser(f))
    print f
    if exists(f):
        if ismacos():
            macos.shell("sudo %s %s install" % (bin,f))
            return True
        if iswindows():
            shell("%s %s install" % (bin,f))
            return True
        raise OSError("%s unsupported yet" % platform.system())

def register(f="setup.py"):
    """run "python setup.py register" """
    f=abspath(expanduser(f))
    if exists(f):
        r=shell("python %s register" % f)
        if not r.find("Server response (200): OK")>0:
            raise Exception(r)

def upload(f="setup.py",distribution="sdist"):
    """run "python setup.py %s upload" """
    f=abspath(expanduser(f))
    if exists(f):
        register(f)
        command="python %s %s upload" % (f,distribution)
        result=shell(command)
        if result.find("Server response (200): OK")>0:
            return True
        if result.find("you should create a new release")>0:
            raise Exception(result.splitlines()[-2:])
        raise Exception(result)

#def bdist_upload(f="setup.py"):
    #return upload(f,"bdist")

def sdist_upload(f="setup.py"):
    return upload(f,"sdist")